@@ -5,6 +5,7 @@ use crate::ross_convert_packet::RossConvertPacket;
 use crate::ross_event::ross_configurator_event::*;
 use crate::ross_event::ross_event_code::*;
 use crate::ross_packet::RossPacket;
+use crate::ross_protocol::BROADCAST_ADDRESS;
 
 const EVENT_PACKET: RossPacket = RossPacket {
     is_error: false,
@@ -28,6 +29,7 @@ fn to_packet_configurator_hello_event_test() {
     let configurator_hello_event = RossConfiguratorHelloEvent {};
 
     let mut packet = EVENT_PACKET;
+    packet.device_address = BROADCAST_ADDRESS;
     packet.data = vec![
         ((ROSS_CONFIGURATOR_HELLO_EVENT_CODE >> 8) & 0xff) as u8, // event code
         ((ROSS_CONFIGURATOR_HELLO_EVENT_CODE >> 0) & 0xff) as u8, // event code
